import './index.scss';
import fetchAnnotationsData from './js/fetchAnnotationsData';
import { detectHighlight } from './js/detectHighlight';
import Cookies from 'js-cookie';
import * as Sentry from '@sentry/browser';
import { BrowserTracing } from '@sentry/tracing';
import { initTooltip } from './js/renderTooltip';

Sentry.init({
	// eslint-disable-next-line no-undef
	dsn: process.env.SENTRY_DNS,
	integrations: [new BrowserTracing()],
});

const initAnnotations = async (url) => {
	const sessionCookie = Cookies.get('FTSession_s');

	if (sessionCookie === undefined) {
		const url = new URL('login', 'https://accounts.ft.com');
		url.searchParams.append('location', window.location.href);
		return window.location.replace(url.toString());
	}

	const annotations = await fetchAnnotationsData(url);

	annotations.forEach(detectHighlight);
};

const init = () => {
	try {
		const params = new URLSearchParams(window.location.search);
	
		// If there's an annotations query parameter in the URL, assume we're going to render annotations.
		if (params.get('annotations') === 'true') {
			initAnnotations(window.location.href);
		}
		
		// Initialise the annotation tooltip.
		initTooltip();
	} catch (error) {
		Sentry.captureException(error);
	}

};

export default {
	init,
};
