import { renderHighlight } from './renderHighlight';

const missingHighlightMessage = '<div data-attribute="missing-highlight-message" class="missing-highlight-message"><div class="o-message o-message--alert o-message--inner o-message--neutral" data-o-component="o-message"><div class="o-message__container"><div class="o-message__content missing-highlight-content"><p class="o-message__content-main"><span class="o-message__content-detail">This article was updated. Your highlight can no longer be displayed.</span></p></div></div></div></div>';

export const detectHighlight = (annotation) => {
	// Get the target prefix, root and suffix from the annotation object.
	const { targetPrefix, targetRoot, targetSuffix } = annotation;

	// Decode the annotation sections.
	const decodedPrefix = decodeURIComponent(targetPrefix);
	const decodedRoot = decodeURIComponent(targetRoot);
	const decodedSuffix = decodeURIComponent(targetSuffix);

	// Construct the target string to find. It's possible for the prefix and suffix to be
	//  empty strings but never the root.
	const targetString = decodedPrefix + decodedRoot + decodedSuffix;

	// Select the article content body.
	const articleBody = document.querySelector('[data-attribute="article-content-body"]');

	// Create an array from the child nodes of the article body.
	const nodes = Array.from(articleBody.childNodes);

	// Find the paragraph which includes the target string. We need to check for the whole
	// string because there may be occasions where the root is repeated throughout the article.
	// In these instances, the prefix and suffix will help us to identify the correct instance of
	// the root to highlight.
	const paragraph = nodes.find((n) => n.textContent.includes(targetString));

	if (paragraph) {
		// Get the text content of the paragraph.
		const paragraphText = paragraph.textContent;

		// Get the start index of the text within the paragraph.
		const startIndex = paragraphText.indexOf(decodedRoot);
		// Get the end index of the text within the paragraph.
		const endIndex = startIndex + decodedRoot.length;

		renderHighlight(paragraph, paragraphText, startIndex, endIndex);
	} else {
		const existingBanner = document.querySelector('[data-attribute="missing-highlight-message"]');

		if (!existingBanner) {
			articleBody.innerHTML = missingHighlightMessage + articleBody.innerHTML;
		}
	}
};
