/**
* @jest-environment jsdom
*/

import { detectHighlight } from './detectHighlight';
import { renderHighlight } from './renderHighlight';

const testDOM = '<div data-attribute="article-content-body"><p id="paragraph">Lorem ipsum dolor <a href="#">sit amet, consectetur</a> adipiscing elit</p><div id="tooltip"></div></div>';

let paragraph;

jest.mock('./renderHighlight', () => ({
	renderHighlight: jest.fn(),
}));

describe('When detectHighlight function runs', () => {
	beforeEach(() => {
		document.body.innerHTML = testDOM;

		paragraph = document.getElementById('paragraph');
	});

	it('Should call renderHighlight with the correct data if the highlight is found', () => {
		const annotation = {
			author: 'XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX',
			bodyType: 'TextualBody',
			bodyValue: '',
			id: 'XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX',
			publishedAt: 'XXXX-XX-XXTXX:XX:XX.XXXZ',
			targetArticleId: 'XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX',
			targetPrefix: '',
			targetRoot: 'Lorem%20ipsum',
			targetSuffix: '%20dolor%20',
			isPublished: true,
		};

		detectHighlight(annotation);

		expect(renderHighlight).toHaveBeenCalledWith(paragraph, paragraph.textContent, 0, 11);
	});
});
