import { createAnnotation } from './createAnnotation';
import { renderHighlight } from './renderHighlight';

const MAXIMUM_PREFIX_SUFFIX_LENGTH = 20;

export const handleHighlightButtonPress = (selection, paragraph, text, tooltip) => {
	// Get the text content of the paragraph.
	const paragraphText = paragraph.textContent;

	// Get the start index of the text within the paragraph.
	const startIndex = paragraphText.indexOf(text);
	// Get the end index of the text within the paragraph.
	const endIndex = startIndex + text.length;
	
	// Find a small section of text before and after the selected text within the paragraph. This is to
	// enable detecting the annotation position again even if the article content has changed elsewhere.
	// If the user has selected the whole paragraph these will be empty strings but that's fine, because
	// we assume each paragraph within the article is unique.

	// Get the paragraph text immediately before the selected text, up to a maximum length.
	const prefix = paragraphText.slice(Math.max(0, (startIndex - MAXIMUM_PREFIX_SUFFIX_LENGTH)), startIndex);
	// Get the paragraph text immediately after the selected text, up to a maximum length.
	const suffix = paragraphText.slice(endIndex, endIndex + MAXIMUM_PREFIX_SUFFIX_LENGTH);

	const targetArticleId = window.location.pathname.split('/content/').pop();

	// Construct the annotation object.
	const annotation = {
		targetArticleId,
		targetPrefix: encodeURIComponent(prefix),
		targetRoot: encodeURIComponent(text),
		targetSuffix: encodeURIComponent(suffix),
	};

	createAnnotation(annotation);

	renderHighlight(paragraph, paragraphText, startIndex, endIndex);

	// Clear the user's selection, which may now look wrong because the underlying DOM has changed.
	selection.empty();

	tooltip.classList.add('hidden');
};