/**
* @jest-environment jsdom
*/

import { createAnnotation } from './createAnnotation';
import { handleHighlightButtonPress } from './highlightButton';
import { renderHighlight } from './renderHighlight';

jest.mock('./createAnnotation', () => ({
	createAnnotation: jest.fn(),
}));

jest.mock('./renderHighlight', () => ({
	renderHighlight: jest.fn(),
}));

const testDOM = '<div><p id="paragraph">Lorem ipsum dolor <a href="#">sit amet, consectetur</a> adipiscing elit</p><div id="tooltip"></div></div>';

let paragraph;
let tooltip;

const selection = {
	empty: () => jest.fn(),
};

describe('When highlight button is pressed', () => {
	beforeEach(() => {
		document.body.innerHTML = testDOM;

		paragraph = document.getElementById('paragraph');
		tooltip = document.getElementById('tooltip');
	});

	test('Correctly attempts creating an annotation with text content across multiple nodes', () => {
		const text = 'Lorem ipsum dolor sit amet, consectetur adipiscing elit';

		handleHighlightButtonPress(selection, paragraph, text, tooltip);

		const annotation = {
			targetArticleId: '/',
			targetPrefix: '',
			targetRoot: encodeURIComponent(text),
			targetSuffix: '',
		};

		expect(createAnnotation).toHaveBeenCalledWith(annotation);
		expect(renderHighlight).toHaveBeenCalledWith(paragraph, text, 0, text.length);
		expect(tooltip.classList.contains('hidden')).toBe(true);
	});
});
