export const renderHighlight = (paragraph, paragraphText, startIndex, endIndex) => {
	// Create an array from the paragraph's child nodes.
	const paragraphNodes = Array.from(paragraph.childNodes);

	// Establish a cursor to move through the nodes.
	let cursor = 0;

	// Map across the nodes. We need to do this to ensure that elements within paragraphs,
	// for example links, are highlighted and preserved correctly.
	paragraphNodes.forEach((n) => {
		const endOfPart = cursor + n.textContent.length;
	
		// Check whether the selection covers the entire part.
		if (startIndex < cursor && endIndex > endOfPart) {
			// Text nodes cannot contain child nodes. So if it's a text node, create a new element,
			// insert it into the parent node and remove the existing node.
			if (n.nodeType === document.TEXT_NODE) {
				const mark = document.createElement('mark');
				mark.innerHTML = n.textContent;
				n.parentNode.insertBefore(mark, n);
				n.parentNode.removeChild(n);
				// If it's an element node, wrap the relevant part in a <mark>.
			} else if (n.nodeType === document.ELEMENT_NODE) {
				n.innerHTML = `<mark>${n.textContent}</mark>`;
			}
	
			// Check whether the selection start and ends within the part.
		} else if (startIndex >= cursor && endIndex <= endOfPart) {
			// Text nodes cannot contain child nodes. So if it's a text node, create a new element,
			// insert it into the parent node and remove the existing node.
			if (n.nodeType === document.TEXT_NODE) {
				n.parentNode.insertBefore(document.createTextNode(paragraphText.slice(cursor, startIndex)), n);
				const mark = document.createElement('mark');
				mark.innerHTML = paragraphText.slice(startIndex, endIndex);
				n.parentNode.insertBefore(mark, n);
				n.parentNode.insertBefore(document.createTextNode(paragraphText.slice(endIndex, endOfPart)), n);
				n.parentNode.removeChild(n);
				// If it's an element node, wrap the relevant part in a <mark>.
			} else if (n.nodeType === document.ELEMENT_NODE) {
				n.innerHTML = `${paragraphText.slice(cursor, startIndex)}<mark>${paragraphText.slice(startIndex, endIndex)}</mark>${paragraphText.slice(endIndex, endOfPart)}`;
			}
	
			// Check whether the selection starts within the part.
		} else if (startIndex >= cursor && startIndex < endOfPart) {
			// Text nodes cannot contain child nodes. So if it's a text node, create a new element,
			// insert it into the parent node and remove the existing node.
			if (n.nodeType === document.TEXT_NODE) {
				n.parentNode.insertBefore(document.createTextNode(paragraphText.slice(cursor, startIndex)), n);
				const mark = document.createElement('mark');
				mark.innerHTML = paragraphText.slice(startIndex, endOfPart);
				n.parentNode.insertBefore(mark, n);
				n.parentNode.removeChild(n);
				// If it's an element node, wrap the relevant part in a <mark>.
			} else if (n.nodeType === document.ELEMENT_NODE) {
				n.innerHTML = `${paragraphText.slice(cursor, startIndex)}<mark>${paragraphText.slice(startIndex, endOfPart)}</mark>`;
			}
	
			// Check whether the selection ends within the part.
		} else if (endIndex > cursor && endIndex <= endOfPart) {
			// Text nodes cannot contain child nodes. So if it's a text node, create a new element,
			// insert it into the parent node and remove the existing node.
			if (n.nodeType === document.TEXT_NODE) {
				const mark = document.createElement('mark');
				mark.innerHTML = paragraphText.slice(cursor, endIndex);
				n.parentNode.insertBefore(mark, n);
				n.parentNode.insertBefore(document.createTextNode(paragraphText.slice(endIndex, endOfPart)), n);
				n.parentNode.removeChild(n);
				// If it's an element node, wrap the relevant part in a <mark>.
			} else if (n.nodeType === document.ELEMENT_NODE) {
				n.innerHTML = `<mark>${paragraphText.slice(cursor, endIndex)}</mark>${paragraphText.slice(endIndex, endOfPart)}`;
			}
		}
	
		// Increase the cursor by the length of the node's text content.
		cursor += n.textContent.length;
	});
};
