/**
* @jest-environment jsdom
*/

import { renderHighlight } from './renderHighlight';

const testDOM = '<div data-attribute="article-content-body"><p id="paragraph">Lorem ipsum dolor <a href="#">sit amet, consectetur</a> adipiscing elit</p></div>';

let paragraph;

describe('When renderHighlight function runs', () => {
	beforeEach(() => {
		document.body.innerHTML = testDOM;

		paragraph = document.getElementById('paragraph');
	});

	it('Should insert a highlight correctly across nodes', () => {
		renderHighlight(paragraph, paragraph.textContent, 0, 55);

		expect(document.body.innerHTML).toEqual('<div data-attribute="article-content-body"><p id="paragraph"><mark>Lorem ipsum dolor </mark><a href="#"><mark>sit amet, consectetur</mark></a><mark> adipiscing elit</mark></p></div>');
	});

	it('Should insert a highlight correctly in a child node', () => {
		renderHighlight(paragraph, paragraph.textContent, 20, 30);

		expect(document.body.innerHTML).toEqual('<div data-attribute="article-content-body"><p id="paragraph">Lorem ipsum dolor <a href="#">si<mark>t amet, co</mark>nsectetur</a> adipiscing elit</p></div>');
	});

	it('Should insert a highlight correctly which begins and ends in different', () => {
		renderHighlight(paragraph, paragraph.textContent, 0, 20);

		expect(document.body.innerHTML).toEqual('<div data-attribute="article-content-body"><p id="paragraph"><mark>Lorem ipsum dolor </mark><a href="#"><mark>si</mark>t amet, consectetur</a> adipiscing elit</p></div>');
	});
});
